@@ -16,11 +16,11 @@ use Symbol                  qw( qualify_to_ref  );
 # package variables & sanity checks
 ########################################################################
 
-our $VERSION    = version->parse( 'v0.0.2' )->numify;
+our $VERSION    = version->parse( 'v0.1.0' )->numify;
 
 my $nil         = sub{};
 
-my @checkout    = qw( git checkout --detach );
+my @checkout    = qw( git checkout          );
 my @restore     = qw( git checkout --theirs );
 
 ########################################################################
@@ -37,13 +37,18 @@ sub source_prefix
 sub module_sources
 {
     my $extract = shift;
-    my $prefix  = $extract->value( 'git_prefix' );
+    my $prefix  = $extract->value( 'git_prefix' ) . '*';
 
     # force a list context for qx
 
-    ( qx{ git tag --list $prefix* } )
-    or 
-    die "No tags like '$prefix*' found"
+    chomp( my @tagz = qx{ git tag --list '$prefix'} )
+    or
+    die "No tags like '$prefix*' found";
+
+    local $,    = "\n#\t";
+    print "# Git tags: '$prefix*'", @tagz;
+
+    @tagz
 }
 
 sub source_files
@@ -60,18 +65,37 @@ sub get_files
 
     # deal with parsing this iff cleanup is called.
 
-    $extract->value( restore_branch => qx{ git branch } );
+    chomp( my $curr = ( qx{ git branch } )[0] );
+
+    print "# Saving: '$curr' for cleanup.";
+
+    $extract->value( restore_branch => $curr );
 
     # no telling what the tag might look like.
     # quotes protect it from the shell.
 
-    system @checkout, "'$tag'"
-    and
-    do
+    my @status
+    = do
     {
-        local $, = ' ';
+        local $,    = ' ';
+
+        qx{ @checkout '$tag' }
+    };
+
+    if( $? )
+    {
+        local $, = "\n@\t";
+
+        chomp @status;
+
+        print 'Checkout result:', @status;
+
         warn "Non-zero exit: $? from @checkout '$tag'";
     }
+    else
+    {
+        print "# Checkout '$tag' complete.";
+    }
 }
 
 sub cleanup
